| Title: | Using Quarto Extensions Designed for Cancer Registry Reports |
|---|---|
| Description: | Provides Quarto extension templates, styles, and helper functions for generating high-quality cancer registry reports. |
| Authors: | Qiong Chen [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-2401-0046>, affiliation: Department of Cancer Epidemiology, The Affiliated Cancer Hospital of Zhengzhou University & Henan Cancer Hospital, Henan Cancer Registry in China) |
| Maintainer: | Qiong Chen <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-05 08:00:51 UTC |
| Source: | https://github.com/gigu003/crformats |
Copy an Internal File from the Package
copy_internal_file(folder, file, dest, overwrite = FALSE)copy_internal_file(folder, file, dest, overwrite = FALSE)
folder |
A string indicating the internal folder in the package
(relative to |
file |
A string specifying the name of the file to copy. |
dest |
A string specifying the destination path (including filename) to copy the file to. |
overwrite |
Logical; if |
NULL (invisibly). The function is called for its side effect of
copying a file.
List available docx templates in the package
ls_docx()ls_docx()
A character vector of docx template file names.
ls_docx()ls_docx()
List bundled Quarto extensions
ls_ext()ls_ext()
a string of available extensions for install
ls_ext()ls_ext()
Use the docx templates in the manuscript package
use_docx_template(name = "chinese", overwrite = TRUE)use_docx_template(name = "chinese", overwrite = TRUE)
name |
Name of the docx template. |
overwrite |
Whether to overwrite the template file if it exists. |
Path of the created/used template.
## Not run: use_docx_template("chinese") ## End(Not run)## Not run: use_docx_template("chinese") ## End(Not run)
Install bundled Quarto extensions into specified directory
use_quarto_ext( ext_name = "qcreport", dir = NULL, use_qmd = TRUE, qmd_name = "index" )use_quarto_ext( ext_name = "qcreport", dir = NULL, use_qmd = TRUE, qmd_name = "index" )
ext_name |
String indicating which extension to install |
dir |
Character string indicating where extension to install |
use_qmd |
Logical, whether to copy default qmd file |
qmd_name |
Name for the .qmd file (default is 'index.qmd') |
a message if extension was successfully copied over
## Not run: use_quarto_ext("qcreport") ## End(Not run)## Not run: use_quarto_ext("qcreport") ## End(Not run)